# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['WorkspaceApiVersionSetArgs', 'WorkspaceApiVersionSet']

@pulumi.input_type
class WorkspaceApiVersionSetArgs:
    def __init__(__self__, *,
                 api_management_workspace_id: pulumi.Input[_builtins.str],
                 display_name: pulumi.Input[_builtins.str],
                 versioning_scheme: pulumi.Input[_builtins.str],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 version_header_name: Optional[pulumi.Input[_builtins.str]] = None,
                 version_query_name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a WorkspaceApiVersionSet resource.

        :param pulumi.Input[_builtins.str] api_management_workspace_id: Specifies the ID of the API Management Workspace. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] display_name: Specifies the display name of the API Management Workspace API Version Set.
        :param pulumi.Input[_builtins.str] versioning_scheme: Specifies where in a request that the API Version should be read from. Possible values are `Header`, `Query` and `Segment`.
        :param pulumi.Input[_builtins.str] description: Specifies the description of the API Management Workspace API Version Set.
        :param pulumi.Input[_builtins.str] name: Specifies the name of the API Management Workspace API Version Set. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] version_header_name: Specifies the name of the header to read from inbound requests to determine the API version.
        :param pulumi.Input[_builtins.str] version_query_name: Specifies the name of the query string parameter to read from inbound requests to determine the API version.
        """
        pulumi.set(__self__, "api_management_workspace_id", api_management_workspace_id)
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "versioning_scheme", versioning_scheme)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if version_header_name is not None:
            pulumi.set(__self__, "version_header_name", version_header_name)
        if version_query_name is not None:
            pulumi.set(__self__, "version_query_name", version_query_name)

    @_builtins.property
    @pulumi.getter(name="apiManagementWorkspaceId")
    def api_management_workspace_id(self) -> pulumi.Input[_builtins.str]:
        """
        Specifies the ID of the API Management Workspace. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "api_management_workspace_id")

    @api_management_workspace_id.setter
    def api_management_workspace_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "api_management_workspace_id", value)

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Input[_builtins.str]:
        """
        Specifies the display name of the API Management Workspace API Version Set.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "display_name", value)

    @_builtins.property
    @pulumi.getter(name="versioningScheme")
    def versioning_scheme(self) -> pulumi.Input[_builtins.str]:
        """
        Specifies where in a request that the API Version should be read from. Possible values are `Header`, `Query` and `Segment`.
        """
        return pulumi.get(self, "versioning_scheme")

    @versioning_scheme.setter
    def versioning_scheme(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "versioning_scheme", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the description of the API Management Workspace API Version Set.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the name of the API Management Workspace API Version Set. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="versionHeaderName")
    def version_header_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the name of the header to read from inbound requests to determine the API version.
        """
        return pulumi.get(self, "version_header_name")

    @version_header_name.setter
    def version_header_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "version_header_name", value)

    @_builtins.property
    @pulumi.getter(name="versionQueryName")
    def version_query_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the name of the query string parameter to read from inbound requests to determine the API version.
        """
        return pulumi.get(self, "version_query_name")

    @version_query_name.setter
    def version_query_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "version_query_name", value)


@pulumi.input_type
class _WorkspaceApiVersionSetState:
    def __init__(__self__, *,
                 api_management_workspace_id: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 version_header_name: Optional[pulumi.Input[_builtins.str]] = None,
                 version_query_name: Optional[pulumi.Input[_builtins.str]] = None,
                 versioning_scheme: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering WorkspaceApiVersionSet resources.

        :param pulumi.Input[_builtins.str] api_management_workspace_id: Specifies the ID of the API Management Workspace. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] description: Specifies the description of the API Management Workspace API Version Set.
        :param pulumi.Input[_builtins.str] display_name: Specifies the display name of the API Management Workspace API Version Set.
        :param pulumi.Input[_builtins.str] name: Specifies the name of the API Management Workspace API Version Set. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] version_header_name: Specifies the name of the header to read from inbound requests to determine the API version.
        :param pulumi.Input[_builtins.str] version_query_name: Specifies the name of the query string parameter to read from inbound requests to determine the API version.
        :param pulumi.Input[_builtins.str] versioning_scheme: Specifies where in a request that the API Version should be read from. Possible values are `Header`, `Query` and `Segment`.
        """
        if api_management_workspace_id is not None:
            pulumi.set(__self__, "api_management_workspace_id", api_management_workspace_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if version_header_name is not None:
            pulumi.set(__self__, "version_header_name", version_header_name)
        if version_query_name is not None:
            pulumi.set(__self__, "version_query_name", version_query_name)
        if versioning_scheme is not None:
            pulumi.set(__self__, "versioning_scheme", versioning_scheme)

    @_builtins.property
    @pulumi.getter(name="apiManagementWorkspaceId")
    def api_management_workspace_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the ID of the API Management Workspace. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "api_management_workspace_id")

    @api_management_workspace_id.setter
    def api_management_workspace_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "api_management_workspace_id", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the description of the API Management Workspace API Version Set.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the display name of the API Management Workspace API Version Set.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "display_name", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the name of the API Management Workspace API Version Set. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="versionHeaderName")
    def version_header_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the name of the header to read from inbound requests to determine the API version.
        """
        return pulumi.get(self, "version_header_name")

    @version_header_name.setter
    def version_header_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "version_header_name", value)

    @_builtins.property
    @pulumi.getter(name="versionQueryName")
    def version_query_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the name of the query string parameter to read from inbound requests to determine the API version.
        """
        return pulumi.get(self, "version_query_name")

    @version_query_name.setter
    def version_query_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "version_query_name", value)

    @_builtins.property
    @pulumi.getter(name="versioningScheme")
    def versioning_scheme(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies where in a request that the API Version should be read from. Possible values are `Header`, `Query` and `Segment`.
        """
        return pulumi.get(self, "versioning_scheme")

    @versioning_scheme.setter
    def versioning_scheme(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "versioning_scheme", value)


@pulumi.type_token("azure:apimanagement/workspaceApiVersionSet:WorkspaceApiVersionSet")
class WorkspaceApiVersionSet(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 api_management_workspace_id: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 version_header_name: Optional[pulumi.Input[_builtins.str]] = None,
                 version_query_name: Optional[pulumi.Input[_builtins.str]] = None,
                 versioning_scheme: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages an API Version Set within an API Management Workspace.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_service = azure.apimanagement.Service("example",
            name="example-apim",
            location=example.location,
            resource_group_name=example.name,
            publisher_name="Example Publisher",
            publisher_email="publisher@example.com",
            sku_name="Premium_1")
        example_workspace = azure.apimanagement.Workspace("example",
            name="example-workspace",
            api_management_id=example_service.id,
            display_name="Example Workspace",
            description="Example workspace for development")
        example_workspace_api_version_set = azure.apimanagement.WorkspaceApiVersionSet("example",
            name="example-version-set",
            api_management_workspace_id=example_workspace.id,
            display_name="Example API Version Set",
            versioning_scheme="Segment")
        ```

        ## API Providers

        <!-- This section is generated, changes will be overwritten -->
        This resource uses the following Azure API Providers:

        * `Microsoft.ApiManagement` - 2024-05-01

        ## Import

        API Management Workspace API Version Sets can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:apimanagement/workspaceApiVersionSet:WorkspaceApiVersionSet example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.ApiManagement/service/service1/workspaces/workspace1/apiVersionSets/set1
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] api_management_workspace_id: Specifies the ID of the API Management Workspace. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] description: Specifies the description of the API Management Workspace API Version Set.
        :param pulumi.Input[_builtins.str] display_name: Specifies the display name of the API Management Workspace API Version Set.
        :param pulumi.Input[_builtins.str] name: Specifies the name of the API Management Workspace API Version Set. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] version_header_name: Specifies the name of the header to read from inbound requests to determine the API version.
        :param pulumi.Input[_builtins.str] version_query_name: Specifies the name of the query string parameter to read from inbound requests to determine the API version.
        :param pulumi.Input[_builtins.str] versioning_scheme: Specifies where in a request that the API Version should be read from. Possible values are `Header`, `Query` and `Segment`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: WorkspaceApiVersionSetArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages an API Version Set within an API Management Workspace.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_service = azure.apimanagement.Service("example",
            name="example-apim",
            location=example.location,
            resource_group_name=example.name,
            publisher_name="Example Publisher",
            publisher_email="publisher@example.com",
            sku_name="Premium_1")
        example_workspace = azure.apimanagement.Workspace("example",
            name="example-workspace",
            api_management_id=example_service.id,
            display_name="Example Workspace",
            description="Example workspace for development")
        example_workspace_api_version_set = azure.apimanagement.WorkspaceApiVersionSet("example",
            name="example-version-set",
            api_management_workspace_id=example_workspace.id,
            display_name="Example API Version Set",
            versioning_scheme="Segment")
        ```

        ## API Providers

        <!-- This section is generated, changes will be overwritten -->
        This resource uses the following Azure API Providers:

        * `Microsoft.ApiManagement` - 2024-05-01

        ## Import

        API Management Workspace API Version Sets can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:apimanagement/workspaceApiVersionSet:WorkspaceApiVersionSet example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.ApiManagement/service/service1/workspaces/workspace1/apiVersionSets/set1
        ```


        :param str resource_name: The name of the resource.
        :param WorkspaceApiVersionSetArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(WorkspaceApiVersionSetArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 api_management_workspace_id: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 version_header_name: Optional[pulumi.Input[_builtins.str]] = None,
                 version_query_name: Optional[pulumi.Input[_builtins.str]] = None,
                 versioning_scheme: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = WorkspaceApiVersionSetArgs.__new__(WorkspaceApiVersionSetArgs)

            if api_management_workspace_id is None and not opts.urn:
                raise TypeError("Missing required property 'api_management_workspace_id'")
            __props__.__dict__["api_management_workspace_id"] = api_management_workspace_id
            __props__.__dict__["description"] = description
            if display_name is None and not opts.urn:
                raise TypeError("Missing required property 'display_name'")
            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["name"] = name
            __props__.__dict__["version_header_name"] = version_header_name
            __props__.__dict__["version_query_name"] = version_query_name
            if versioning_scheme is None and not opts.urn:
                raise TypeError("Missing required property 'versioning_scheme'")
            __props__.__dict__["versioning_scheme"] = versioning_scheme
        super(WorkspaceApiVersionSet, __self__).__init__(
            'azure:apimanagement/workspaceApiVersionSet:WorkspaceApiVersionSet',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            api_management_workspace_id: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            display_name: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            version_header_name: Optional[pulumi.Input[_builtins.str]] = None,
            version_query_name: Optional[pulumi.Input[_builtins.str]] = None,
            versioning_scheme: Optional[pulumi.Input[_builtins.str]] = None) -> 'WorkspaceApiVersionSet':
        """
        Get an existing WorkspaceApiVersionSet resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] api_management_workspace_id: Specifies the ID of the API Management Workspace. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] description: Specifies the description of the API Management Workspace API Version Set.
        :param pulumi.Input[_builtins.str] display_name: Specifies the display name of the API Management Workspace API Version Set.
        :param pulumi.Input[_builtins.str] name: Specifies the name of the API Management Workspace API Version Set. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] version_header_name: Specifies the name of the header to read from inbound requests to determine the API version.
        :param pulumi.Input[_builtins.str] version_query_name: Specifies the name of the query string parameter to read from inbound requests to determine the API version.
        :param pulumi.Input[_builtins.str] versioning_scheme: Specifies where in a request that the API Version should be read from. Possible values are `Header`, `Query` and `Segment`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _WorkspaceApiVersionSetState.__new__(_WorkspaceApiVersionSetState)

        __props__.__dict__["api_management_workspace_id"] = api_management_workspace_id
        __props__.__dict__["description"] = description
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["name"] = name
        __props__.__dict__["version_header_name"] = version_header_name
        __props__.__dict__["version_query_name"] = version_query_name
        __props__.__dict__["versioning_scheme"] = versioning_scheme
        return WorkspaceApiVersionSet(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="apiManagementWorkspaceId")
    def api_management_workspace_id(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies the ID of the API Management Workspace. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "api_management_workspace_id")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies the description of the API Management Workspace API Version Set.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies the display name of the API Management Workspace API Version Set.
        """
        return pulumi.get(self, "display_name")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies the name of the API Management Workspace API Version Set. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="versionHeaderName")
    def version_header_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies the name of the header to read from inbound requests to determine the API version.
        """
        return pulumi.get(self, "version_header_name")

    @_builtins.property
    @pulumi.getter(name="versionQueryName")
    def version_query_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies the name of the query string parameter to read from inbound requests to determine the API version.
        """
        return pulumi.get(self, "version_query_name")

    @_builtins.property
    @pulumi.getter(name="versioningScheme")
    def versioning_scheme(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies where in a request that the API Version should be read from. Possible values are `Header`, `Query` and `Segment`.
        """
        return pulumi.get(self, "versioning_scheme")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetShareResult',
    'AwaitableGetShareResult',
    'get_share',
    'get_share_output',
]

@pulumi.output_type
class GetShareResult:
    """
    A collection of values returned by getShare.
    """
    def __init__(__self__, acls=None, id=None, metadata=None, name=None, quota=None, resource_manager_id=None, storage_account_id=None, storage_account_name=None):
        if acls and not isinstance(acls, list):
            raise TypeError("Expected argument 'acls' to be a list")
        pulumi.set(__self__, "acls", acls)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if metadata and not isinstance(metadata, dict):
            raise TypeError("Expected argument 'metadata' to be a dict")
        pulumi.set(__self__, "metadata", metadata)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if quota and not isinstance(quota, int):
            raise TypeError("Expected argument 'quota' to be a int")
        pulumi.set(__self__, "quota", quota)
        if resource_manager_id and not isinstance(resource_manager_id, str):
            raise TypeError("Expected argument 'resource_manager_id' to be a str")
        pulumi.set(__self__, "resource_manager_id", resource_manager_id)
        if storage_account_id and not isinstance(storage_account_id, str):
            raise TypeError("Expected argument 'storage_account_id' to be a str")
        pulumi.set(__self__, "storage_account_id", storage_account_id)
        if storage_account_name and not isinstance(storage_account_name, str):
            raise TypeError("Expected argument 'storage_account_name' to be a str")
        pulumi.set(__self__, "storage_account_name", storage_account_name)

    @_builtins.property
    @pulumi.getter
    def acls(self) -> Optional[Sequence['outputs.GetShareAclResult']]:
        """
        One or more acl blocks as defined below.
        """
        return pulumi.get(self, "acls")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def metadata(self) -> Mapping[str, _builtins.str]:
        """
        A map of custom file share metadata.
        """
        return pulumi.get(self, "metadata")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def quota(self) -> _builtins.int:
        """
        The quota of the File Share in GB.
        """
        return pulumi.get(self, "quota")

    @_builtins.property
    @pulumi.getter(name="resourceManagerId")
    @_utilities.deprecated("""this property has been deprecated in favour of `id` and will be removed in version 5.0 of the Provider.""")
    def resource_manager_id(self) -> _builtins.str:
        return pulumi.get(self, "resource_manager_id")

    @_builtins.property
    @pulumi.getter(name="storageAccountId")
    def storage_account_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "storage_account_id")

    @_builtins.property
    @pulumi.getter(name="storageAccountName")
    def storage_account_name(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "storage_account_name")


class AwaitableGetShareResult(GetShareResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetShareResult(
            acls=self.acls,
            id=self.id,
            metadata=self.metadata,
            name=self.name,
            quota=self.quota,
            resource_manager_id=self.resource_manager_id,
            storage_account_id=self.storage_account_id,
            storage_account_name=self.storage_account_name)


def get_share(acls: Optional[Sequence[Union['GetShareAclArgs', 'GetShareAclArgsDict']]] = None,
              metadata: Optional[Mapping[str, _builtins.str]] = None,
              name: Optional[_builtins.str] = None,
              storage_account_id: Optional[_builtins.str] = None,
              storage_account_name: Optional[_builtins.str] = None,
              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetShareResult:
    """
    Use this data source to access information about an existing File Share.

    > **Note:** Shared Key authentication will always be used for this data source, as AzureAD authentication is not supported by the Storage API for files.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.storage.get_account(name="exampleaccount",
        resource_group_name="examples")
    example_get_share = azure.storage.get_share(name="existing",
        storage_account_id=example.id)
    ```

    ## API Providers

    <!-- This section is generated, changes will be overwritten -->
    This data source uses the following Azure API Providers:

    * `Microsoft.Storage` - 2023-05-01


    :param Sequence[Union['GetShareAclArgs', 'GetShareAclArgsDict']] acls: One or more acl blocks as defined below.
    :param Mapping[str, _builtins.str] metadata: A map of custom file share metadata.
    :param _builtins.str name: The name of the share.
    :param _builtins.str storage_account_id: The ID of the storage account in which the share exists.
           
           > **Note:** One of `storage_account_name` or `storage_account_id` must be specified. When specifying `storage_account_id` the resource will use the Resource Manager API, rather than the Data Plane API.
    :param _builtins.str storage_account_name: The name of the storage account in which the share exists. This property is deprecated in favour of `storage_account_id`.
    """
    __args__ = dict()
    __args__['acls'] = acls
    __args__['metadata'] = metadata
    __args__['name'] = name
    __args__['storageAccountId'] = storage_account_id
    __args__['storageAccountName'] = storage_account_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('azure:storage/getShare:getShare', __args__, opts=opts, typ=GetShareResult).value

    return AwaitableGetShareResult(
        acls=pulumi.get(__ret__, 'acls'),
        id=pulumi.get(__ret__, 'id'),
        metadata=pulumi.get(__ret__, 'metadata'),
        name=pulumi.get(__ret__, 'name'),
        quota=pulumi.get(__ret__, 'quota'),
        resource_manager_id=pulumi.get(__ret__, 'resource_manager_id'),
        storage_account_id=pulumi.get(__ret__, 'storage_account_id'),
        storage_account_name=pulumi.get(__ret__, 'storage_account_name'))
def get_share_output(acls: Optional[pulumi.Input[Optional[Sequence[Union['GetShareAclArgs', 'GetShareAclArgsDict']]]]] = None,
                     metadata: Optional[pulumi.Input[Optional[Mapping[str, _builtins.str]]]] = None,
                     name: Optional[pulumi.Input[_builtins.str]] = None,
                     storage_account_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     storage_account_name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetShareResult]:
    """
    Use this data source to access information about an existing File Share.

    > **Note:** Shared Key authentication will always be used for this data source, as AzureAD authentication is not supported by the Storage API for files.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.storage.get_account(name="exampleaccount",
        resource_group_name="examples")
    example_get_share = azure.storage.get_share(name="existing",
        storage_account_id=example.id)
    ```

    ## API Providers

    <!-- This section is generated, changes will be overwritten -->
    This data source uses the following Azure API Providers:

    * `Microsoft.Storage` - 2023-05-01


    :param Sequence[Union['GetShareAclArgs', 'GetShareAclArgsDict']] acls: One or more acl blocks as defined below.
    :param Mapping[str, _builtins.str] metadata: A map of custom file share metadata.
    :param _builtins.str name: The name of the share.
    :param _builtins.str storage_account_id: The ID of the storage account in which the share exists.
           
           > **Note:** One of `storage_account_name` or `storage_account_id` must be specified. When specifying `storage_account_id` the resource will use the Resource Manager API, rather than the Data Plane API.
    :param _builtins.str storage_account_name: The name of the storage account in which the share exists. This property is deprecated in favour of `storage_account_id`.
    """
    __args__ = dict()
    __args__['acls'] = acls
    __args__['metadata'] = metadata
    __args__['name'] = name
    __args__['storageAccountId'] = storage_account_id
    __args__['storageAccountName'] = storage_account_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('azure:storage/getShare:getShare', __args__, opts=opts, typ=GetShareResult)
    return __ret__.apply(lambda __response__: GetShareResult(
        acls=pulumi.get(__response__, 'acls'),
        id=pulumi.get(__response__, 'id'),
        metadata=pulumi.get(__response__, 'metadata'),
        name=pulumi.get(__response__, 'name'),
        quota=pulumi.get(__response__, 'quota'),
        resource_manager_id=pulumi.get(__response__, 'resource_manager_id'),
        storage_account_id=pulumi.get(__response__, 'storage_account_id'),
        storage_account_name=pulumi.get(__response__, 'storage_account_name')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'ClusterIdentity',
    'WorkspaceTableCustomLogColumn',
    'WorkspaceTableCustomLogStandardColumn',
]

@pulumi.output_type
class ClusterIdentity(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "identityIds":
            suggest = "identity_ids"
        elif key == "principalId":
            suggest = "principal_id"
        elif key == "tenantId":
            suggest = "tenant_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ClusterIdentity. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ClusterIdentity.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ClusterIdentity.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 type: _builtins.str,
                 identity_ids: Optional[Sequence[_builtins.str]] = None,
                 principal_id: Optional[_builtins.str] = None,
                 tenant_id: Optional[_builtins.str] = None):
        """
        :param _builtins.str type: Specifies the type of Managed Service Identity that should be configured on this Log Analytics Cluster. Possible values are `SystemAssigned` and `UserAssigned`. Changing this forces a new resource to be created.
               
               > **Note:** The assigned `principal_id` and `tenant_id` can be retrieved after the identity `type` has been set to `SystemAssigned` and the Log Analytics Cluster has been created. More details are available below.
        :param Sequence[_builtins.str] identity_ids: A list of User Assigned Managed Identity IDs to be assigned to this Windows Web App Slot. Changing this forces a new resource to be created.
               
               > **Note:** This is required when `type` is set to `UserAssigned`.
        :param _builtins.str principal_id: The Principal ID associated with this Managed Service Identity.
        :param _builtins.str tenant_id: The Tenant ID associated with this Managed Service Identity.
        """
        pulumi.set(__self__, "type", type)
        if identity_ids is not None:
            pulumi.set(__self__, "identity_ids", identity_ids)
        if principal_id is not None:
            pulumi.set(__self__, "principal_id", principal_id)
        if tenant_id is not None:
            pulumi.set(__self__, "tenant_id", tenant_id)

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        Specifies the type of Managed Service Identity that should be configured on this Log Analytics Cluster. Possible values are `SystemAssigned` and `UserAssigned`. Changing this forces a new resource to be created.

        > **Note:** The assigned `principal_id` and `tenant_id` can be retrieved after the identity `type` has been set to `SystemAssigned` and the Log Analytics Cluster has been created. More details are available below.
        """
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter(name="identityIds")
    def identity_ids(self) -> Optional[Sequence[_builtins.str]]:
        """
        A list of User Assigned Managed Identity IDs to be assigned to this Windows Web App Slot. Changing this forces a new resource to be created.

        > **Note:** This is required when `type` is set to `UserAssigned`.
        """
        return pulumi.get(self, "identity_ids")

    @_builtins.property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> Optional[_builtins.str]:
        """
        The Principal ID associated with this Managed Service Identity.
        """
        return pulumi.get(self, "principal_id")

    @_builtins.property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[_builtins.str]:
        """
        The Tenant ID associated with this Managed Service Identity.
        """
        return pulumi.get(self, "tenant_id")


@pulumi.output_type
class WorkspaceTableCustomLogColumn(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "displayName":
            suggest = "display_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in WorkspaceTableCustomLogColumn. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        WorkspaceTableCustomLogColumn.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        WorkspaceTableCustomLogColumn.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 name: _builtins.str,
                 type: _builtins.str,
                 description: Optional[_builtins.str] = None,
                 display_name: Optional[_builtins.str] = None):
        """
        :param _builtins.str name: Specifies the name of the column.
        :param _builtins.str type: The data type of the column. Possible values are `boolean`, `datetime`, `dynamic`, `guid`, `int`, `long`, `real`, and `string`.
        :param _builtins.str description: The description of the column.
        :param _builtins.str display_name: The display name of the column.
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "type", type)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Specifies the name of the column.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        The data type of the column. Possible values are `boolean`, `datetime`, `dynamic`, `guid`, `int`, `long`, `real`, and `string`.
        """
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[_builtins.str]:
        """
        The description of the column.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[_builtins.str]:
        """
        The display name of the column.
        """
        return pulumi.get(self, "display_name")


@pulumi.output_type
class WorkspaceTableCustomLogStandardColumn(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "displayName":
            suggest = "display_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in WorkspaceTableCustomLogStandardColumn. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        WorkspaceTableCustomLogStandardColumn.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        WorkspaceTableCustomLogStandardColumn.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 description: Optional[_builtins.str] = None,
                 display_name: Optional[_builtins.str] = None,
                 name: Optional[_builtins.str] = None,
                 type: Optional[_builtins.str] = None):
        """
        :param _builtins.str description: The description of the table.
        :param _builtins.str display_name: The display name of the table.
        :param _builtins.str name: Specifies the name of the Log Analytics Workspace Table Custom Log. Changing this forces a new resource to be created.
               
               > **Note:** `name` must end with `_CL`.
        :param _builtins.str type: The data type of the standard column.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[_builtins.str]:
        """
        The description of the table.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[_builtins.str]:
        """
        The display name of the table.
        """
        return pulumi.get(self, "display_name")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Specifies the name of the Log Analytics Workspace Table Custom Log. Changing this forces a new resource to be created.

        > **Note:** `name` must end with `_CL`.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[_builtins.str]:
        """
        The data type of the standard column.
        """
        return pulumi.get(self, "type")





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'AssessmentStatus',
    'AutomationAction',
    'AutomationSource',
    'AutomationSourceRuleSet',
    'AutomationSourceRuleSetRule',
    'SubscriptionPricingExtension',
]

@pulumi.output_type
class AssessmentStatus(dict):
    def __init__(__self__, *,
                 code: _builtins.str,
                 cause: Optional[_builtins.str] = None,
                 description: Optional[_builtins.str] = None):
        """
        :param _builtins.str code: Specifies the programmatic code of the assessment status. Possible values are `Healthy`, `Unhealthy` and `NotApplicable`.
        :param _builtins.str cause: Specifies the cause of the assessment status.
        :param _builtins.str description: Specifies the human readable description of the assessment status.
        """
        pulumi.set(__self__, "code", code)
        if cause is not None:
            pulumi.set(__self__, "cause", cause)
        if description is not None:
            pulumi.set(__self__, "description", description)

    @_builtins.property
    @pulumi.getter
    def code(self) -> _builtins.str:
        """
        Specifies the programmatic code of the assessment status. Possible values are `Healthy`, `Unhealthy` and `NotApplicable`.
        """
        return pulumi.get(self, "code")

    @_builtins.property
    @pulumi.getter
    def cause(self) -> Optional[_builtins.str]:
        """
        Specifies the cause of the assessment status.
        """
        return pulumi.get(self, "cause")

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[_builtins.str]:
        """
        Specifies the human readable description of the assessment status.
        """
        return pulumi.get(self, "description")


@pulumi.output_type
class AutomationAction(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "resourceId":
            suggest = "resource_id"
        elif key == "connectionString":
            suggest = "connection_string"
        elif key == "triggerUrl":
            suggest = "trigger_url"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AutomationAction. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AutomationAction.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AutomationAction.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 resource_id: _builtins.str,
                 connection_string: Optional[_builtins.str] = None,
                 trigger_url: Optional[_builtins.str] = None,
                 type: Optional[_builtins.str] = None):
        """
        :param _builtins.str resource_id: The resource id of the target Logic App, Event Hub namespace or Log Analytics workspace.
        :param _builtins.str connection_string: A connection string to send data to the target Event Hub namespace, this should include a key with send permissions.
               
               > **Note:** `connection_string` is required when `type` is `EventHub`.
        :param _builtins.str trigger_url: The callback URL to trigger the Logic App that will receive and process data sent by this automation. This can be found in the Azure Portal under "See trigger history"
               
               > **Note:** `trigger_url` is required when `type` is `LogicApp`.
        :param _builtins.str type: Type of Azure resource to send data to. Possible values are `EventHub`, `LogicApp` and `Workspace`.
        """
        pulumi.set(__self__, "resource_id", resource_id)
        if connection_string is not None:
            pulumi.set(__self__, "connection_string", connection_string)
        if trigger_url is not None:
            pulumi.set(__self__, "trigger_url", trigger_url)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> _builtins.str:
        """
        The resource id of the target Logic App, Event Hub namespace or Log Analytics workspace.
        """
        return pulumi.get(self, "resource_id")

    @_builtins.property
    @pulumi.getter(name="connectionString")
    def connection_string(self) -> Optional[_builtins.str]:
        """
        A connection string to send data to the target Event Hub namespace, this should include a key with send permissions.

        > **Note:** `connection_string` is required when `type` is `EventHub`.
        """
        return pulumi.get(self, "connection_string")

    @_builtins.property
    @pulumi.getter(name="triggerUrl")
    def trigger_url(self) -> Optional[_builtins.str]:
        """
        The callback URL to trigger the Logic App that will receive and process data sent by this automation. This can be found in the Azure Portal under "See trigger history"

        > **Note:** `trigger_url` is required when `type` is `LogicApp`.
        """
        return pulumi.get(self, "trigger_url")

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[_builtins.str]:
        """
        Type of Azure resource to send data to. Possible values are `EventHub`, `LogicApp` and `Workspace`.
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class AutomationSource(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "eventSource":
            suggest = "event_source"
        elif key == "ruleSets":
            suggest = "rule_sets"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AutomationSource. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AutomationSource.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AutomationSource.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 event_source: _builtins.str,
                 rule_sets: Optional[Sequence['outputs.AutomationSourceRuleSet']] = None):
        """
        :param _builtins.str event_source: Type of data that will trigger this automation. Must be one of `Alerts`, `Assessments`, `AssessmentsSnapshot`, `RegulatoryComplianceAssessment`, `RegulatoryComplianceAssessmentSnapshot`, `SecureScoreControls`, `SecureScoreControlsSnapshot`, `SecureScores`, `SecureScoresSnapshot`, `SubAssessments` or `SubAssessmentsSnapshot`. Note. assessments are also referred to as recommendations
        :param Sequence['AutomationSourceRuleSetArgs'] rule_sets: A set of rules which evaluate upon event and data interception. This is defined in one or more `rule_set` blocks as defined below.
               
               > **Note:** When multiple `rule_set` block are provided, a logical 'OR' is applied to the evaluation of them.
        """
        pulumi.set(__self__, "event_source", event_source)
        if rule_sets is not None:
            pulumi.set(__self__, "rule_sets", rule_sets)

    @_builtins.property
    @pulumi.getter(name="eventSource")
    def event_source(self) -> _builtins.str:
        """
        Type of data that will trigger this automation. Must be one of `Alerts`, `Assessments`, `AssessmentsSnapshot`, `RegulatoryComplianceAssessment`, `RegulatoryComplianceAssessmentSnapshot`, `SecureScoreControls`, `SecureScoreControlsSnapshot`, `SecureScores`, `SecureScoresSnapshot`, `SubAssessments` or `SubAssessmentsSnapshot`. Note. assessments are also referred to as recommendations
        """
        return pulumi.get(self, "event_source")

    @_builtins.property
    @pulumi.getter(name="ruleSets")
    def rule_sets(self) -> Optional[Sequence['outputs.AutomationSourceRuleSet']]:
        """
        A set of rules which evaluate upon event and data interception. This is defined in one or more `rule_set` blocks as defined below.

        > **Note:** When multiple `rule_set` block are provided, a logical 'OR' is applied to the evaluation of them.
        """
        return pulumi.get(self, "rule_sets")


@pulumi.output_type
class AutomationSourceRuleSet(dict):
    def __init__(__self__, *,
                 rules: Sequence['outputs.AutomationSourceRuleSetRule']):
        """
        :param Sequence['AutomationSourceRuleSetRuleArgs'] rules: One or more `rule` blocks as defined below.
               
               > **Note:** This automation will trigger when all of the `rule`s in this `rule_set` are evaluated as 'true'. This is equivalent to a logical 'AND'.
        """
        pulumi.set(__self__, "rules", rules)

    @_builtins.property
    @pulumi.getter
    def rules(self) -> Sequence['outputs.AutomationSourceRuleSetRule']:
        """
        One or more `rule` blocks as defined below.

        > **Note:** This automation will trigger when all of the `rule`s in this `rule_set` are evaluated as 'true'. This is equivalent to a logical 'AND'.
        """
        return pulumi.get(self, "rules")


@pulumi.output_type
class AutomationSourceRuleSetRule(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "expectedValue":
            suggest = "expected_value"
        elif key == "propertyPath":
            suggest = "property_path"
        elif key == "propertyType":
            suggest = "property_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AutomationSourceRuleSetRule. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AutomationSourceRuleSetRule.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AutomationSourceRuleSetRule.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 expected_value: _builtins.str,
                 operator: _builtins.str,
                 property_path: _builtins.str,
                 property_type: _builtins.str):
        """
        :param _builtins.str expected_value: A value that will be compared with the value in `property_path`.
        :param _builtins.str operator: The comparison operator to use, must be one of: `Contains`, `EndsWith`, `Equals`, `GreaterThan`, `GreaterThanOrEqualTo`, `LesserThan`, `LesserThanOrEqualTo`, `NotEquals`, `StartsWith`
        :param _builtins.str property_path: The JPath of the entity model property that should be checked.
        :param _builtins.str property_type: The data type of the compared operands, must be one of: `Integer`, `String`, `Boolean` or `Number`.
               
               > **Note:** The schema for Security Center alerts (when `event_source` is "Alerts") [can be found here](https://docs.microsoft.com/azure/security-center/alerts-schemas?tabs=schema-continuousexport)
        """
        pulumi.set(__self__, "expected_value", expected_value)
        pulumi.set(__self__, "operator", operator)
        pulumi.set(__self__, "property_path", property_path)
        pulumi.set(__self__, "property_type", property_type)

    @_builtins.property
    @pulumi.getter(name="expectedValue")
    def expected_value(self) -> _builtins.str:
        """
        A value that will be compared with the value in `property_path`.
        """
        return pulumi.get(self, "expected_value")

    @_builtins.property
    @pulumi.getter
    def operator(self) -> _builtins.str:
        """
        The comparison operator to use, must be one of: `Contains`, `EndsWith`, `Equals`, `GreaterThan`, `GreaterThanOrEqualTo`, `LesserThan`, `LesserThanOrEqualTo`, `NotEquals`, `StartsWith`
        """
        return pulumi.get(self, "operator")

    @_builtins.property
    @pulumi.getter(name="propertyPath")
    def property_path(self) -> _builtins.str:
        """
        The JPath of the entity model property that should be checked.
        """
        return pulumi.get(self, "property_path")

    @_builtins.property
    @pulumi.getter(name="propertyType")
    def property_type(self) -> _builtins.str:
        """
        The data type of the compared operands, must be one of: `Integer`, `String`, `Boolean` or `Number`.

        > **Note:** The schema for Security Center alerts (when `event_source` is "Alerts") [can be found here](https://docs.microsoft.com/azure/security-center/alerts-schemas?tabs=schema-continuousexport)
        """
        return pulumi.get(self, "property_type")


@pulumi.output_type
class SubscriptionPricingExtension(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "additionalExtensionProperties":
            suggest = "additional_extension_properties"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in SubscriptionPricingExtension. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        SubscriptionPricingExtension.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        SubscriptionPricingExtension.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 name: _builtins.str,
                 additional_extension_properties: Optional[Mapping[str, _builtins.str]] = None):
        """
        :param _builtins.str name: The name of extension.
        :param Mapping[str, _builtins.str] additional_extension_properties: Key/Value pairs that are required for some extensions.
               
               > **Note:** If an extension is not defined, it will not be enabled.
               
               > **Note:** Changing the pricing tier to `Standard` affects all resources of the given type in the subscription and could be quite costly.
        """
        pulumi.set(__self__, "name", name)
        if additional_extension_properties is not None:
            pulumi.set(__self__, "additional_extension_properties", additional_extension_properties)

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The name of extension.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="additionalExtensionProperties")
    def additional_extension_properties(self) -> Optional[Mapping[str, _builtins.str]]:
        """
        Key/Value pairs that are required for some extensions.

        > **Note:** If an extension is not defined, it will not be enabled.

        > **Note:** Changing the pricing tier to `Standard` affects all resources of the given type in the subscription and could be quite costly.
        """
        return pulumi.get(self, "additional_extension_properties")





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'MongoClusterConnectionString',
    'MongoClusterCustomerManagedKey',
    'MongoClusterIdentity',
    'MongoClusterRestore',
    'UserRole',
]

@pulumi.output_type
class MongoClusterConnectionString(dict):
    def __init__(__self__, *,
                 description: Optional[_builtins.str] = None,
                 name: Optional[_builtins.str] = None,
                 value: Optional[_builtins.str] = None):
        """
        :param _builtins.str description: The description of the connection string.
        :param _builtins.str name: The name which should be used for the MongoDB Cluster. Changing this forces a new resource to be created.
        :param _builtins.str value: The value of the Mongo Cluster connection string. The `<user>:<password>` placeholder returned from API will be replaced by the real `administrator_username` and `administrator_password` if available in the state.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[_builtins.str]:
        """
        The description of the connection string.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        The name which should be used for the MongoDB Cluster. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def value(self) -> Optional[_builtins.str]:
        """
        The value of the Mongo Cluster connection string. The `<user>:<password>` placeholder returned from API will be replaced by the real `administrator_username` and `administrator_password` if available in the state.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class MongoClusterCustomerManagedKey(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "keyVaultKeyId":
            suggest = "key_vault_key_id"
        elif key == "userAssignedIdentityId":
            suggest = "user_assigned_identity_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in MongoClusterCustomerManagedKey. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        MongoClusterCustomerManagedKey.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        MongoClusterCustomerManagedKey.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 key_vault_key_id: _builtins.str,
                 user_assigned_identity_id: _builtins.str):
        """
        :param _builtins.str key_vault_key_id: The ID of the key vault key used for encryption. For example: `https://example-vault-name.vault.azure.net/keys/example-key-name`.
        :param _builtins.str user_assigned_identity_id: The ID of the User Assigned Identity that has access to the Key Vault Key.
        """
        pulumi.set(__self__, "key_vault_key_id", key_vault_key_id)
        pulumi.set(__self__, "user_assigned_identity_id", user_assigned_identity_id)

    @_builtins.property
    @pulumi.getter(name="keyVaultKeyId")
    def key_vault_key_id(self) -> _builtins.str:
        """
        The ID of the key vault key used for encryption. For example: `https://example-vault-name.vault.azure.net/keys/example-key-name`.
        """
        return pulumi.get(self, "key_vault_key_id")

    @_builtins.property
    @pulumi.getter(name="userAssignedIdentityId")
    def user_assigned_identity_id(self) -> _builtins.str:
        """
        The ID of the User Assigned Identity that has access to the Key Vault Key.
        """
        return pulumi.get(self, "user_assigned_identity_id")


@pulumi.output_type
class MongoClusterIdentity(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "identityIds":
            suggest = "identity_ids"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in MongoClusterIdentity. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        MongoClusterIdentity.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        MongoClusterIdentity.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 identity_ids: Sequence[_builtins.str],
                 type: _builtins.str):
        """
        :param Sequence[_builtins.str] identity_ids: A list of one or more Resource IDs for User Assigned Managed identities to assign.
               
               > **Note:** Required when `type` is set to `UserAssigned`.
        :param _builtins.str type: The type of managed identity to assign. Possible value is `UserAssigned`.
        """
        pulumi.set(__self__, "identity_ids", identity_ids)
        pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter(name="identityIds")
    def identity_ids(self) -> Sequence[_builtins.str]:
        """
        A list of one or more Resource IDs for User Assigned Managed identities to assign.

        > **Note:** Required when `type` is set to `UserAssigned`.
        """
        return pulumi.get(self, "identity_ids")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        The type of managed identity to assign. Possible value is `UserAssigned`.
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class MongoClusterRestore(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "pointInTimeUtc":
            suggest = "point_in_time_utc"
        elif key == "sourceId":
            suggest = "source_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in MongoClusterRestore. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        MongoClusterRestore.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        MongoClusterRestore.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 point_in_time_utc: _builtins.str,
                 source_id: _builtins.str):
        """
        :param _builtins.str point_in_time_utc: The point in time (in UTC) to restore from, in ISO 8601 format (e.g., `2024-01-01T00:00:00Z`). Changing this forces a new resource to be created.
        :param _builtins.str source_id: The ID of the source MongoDB Cluster to restore from. Changing this forces a new resource to be created.
        """
        pulumi.set(__self__, "point_in_time_utc", point_in_time_utc)
        pulumi.set(__self__, "source_id", source_id)

    @_builtins.property
    @pulumi.getter(name="pointInTimeUtc")
    def point_in_time_utc(self) -> _builtins.str:
        """
        The point in time (in UTC) to restore from, in ISO 8601 format (e.g., `2024-01-01T00:00:00Z`). Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "point_in_time_utc")

    @_builtins.property
    @pulumi.getter(name="sourceId")
    def source_id(self) -> _builtins.str:
        """
        The ID of the source MongoDB Cluster to restore from. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "source_id")


@pulumi.output_type
class UserRole(dict):
    def __init__(__self__, *,
                 database: _builtins.str,
                 name: _builtins.str):
        """
        :param _builtins.str database: The name of the database to which the role will be applied. Changing this forces a new resource to be created.
        :param _builtins.str name: The role name. The only possible value is `root`. Changing this forces a new resource to be created.
        """
        pulumi.set(__self__, "database", database)
        pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter
    def database(self) -> _builtins.str:
        """
        The name of the database to which the role will be applied. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "database")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The role name. The only possible value is `root`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['SingleNodeVirtualInstanceArgs', 'SingleNodeVirtualInstance']

@pulumi.input_type
class SingleNodeVirtualInstanceArgs:
    def __init__(__self__, *,
                 app_location: pulumi.Input[_builtins.str],
                 environment: pulumi.Input[_builtins.str],
                 resource_group_name: pulumi.Input[_builtins.str],
                 sap_fqdn: pulumi.Input[_builtins.str],
                 sap_product: pulumi.Input[_builtins.str],
                 single_server_configuration: pulumi.Input['SingleNodeVirtualInstanceSingleServerConfigurationArgs'],
                 identity: Optional[pulumi.Input['SingleNodeVirtualInstanceIdentityArgs']] = None,
                 location: Optional[pulumi.Input[_builtins.str]] = None,
                 managed_resource_group_name: Optional[pulumi.Input[_builtins.str]] = None,
                 managed_resources_network_access_type: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a SingleNodeVirtualInstance resource.

        :param pulumi.Input[_builtins.str] app_location: The Geo-Location where the SAP system is to be created. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] environment: The environment type for the SAP Single Node Virtual Instance. Possible values are `NonProd` and `Prod`. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] resource_group_name: The name of the Resource Group where the SAP Single Node Virtual Instance should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] sap_fqdn: The fully qualified domain name for the SAP system. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] sap_product: The SAP Product type for the SAP Single Node Virtual Instance. Possible values are `ECC`, `Other` and `S4HANA`. Changing this forces a new resource to be created.
        :param pulumi.Input['SingleNodeVirtualInstanceSingleServerConfigurationArgs'] single_server_configuration: A `single_server_configuration` block as defined below. Changing this forces a new resource to be created.
        :param pulumi.Input['SingleNodeVirtualInstanceIdentityArgs'] identity: An `identity` block as defined below.
        :param pulumi.Input[_builtins.str] location: The Azure Region where the SAP Single Node Virtual Instance should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] managed_resource_group_name: The name of the managed Resource Group for the SAP Single Node Virtual Instance. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] managed_resources_network_access_type: The network access type for managed resources. Possible values are `Private` and `Public`. Defaults to `Public`.
        :param pulumi.Input[_builtins.str] name: Specifies the name of this SAP Single Node Virtual Instance. Changing this forces a new resource to be created.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] tags: A mapping of tags which should be assigned to the SAP Single Node Virtual Instance.
        """
        pulumi.set(__self__, "app_location", app_location)
        pulumi.set(__self__, "environment", environment)
        pulumi.set(__self__, "resource_group_name", resource_group_name)
        pulumi.set(__self__, "sap_fqdn", sap_fqdn)
        pulumi.set(__self__, "sap_product", sap_product)
        pulumi.set(__self__, "single_server_configuration", single_server_configuration)
        if identity is not None:
            pulumi.set(__self__, "identity", identity)
        if location is not None:
            pulumi.set(__self__, "location", location)
        if managed_resource_group_name is not None:
            pulumi.set(__self__, "managed_resource_group_name", managed_resource_group_name)
        if managed_resources_network_access_type is not None:
            pulumi.set(__self__, "managed_resources_network_access_type", managed_resources_network_access_type)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter(name="appLocation")
    def app_location(self) -> pulumi.Input[_builtins.str]:
        """
        The Geo-Location where the SAP system is to be created. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "app_location")

    @app_location.setter
    def app_location(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "app_location", value)

    @_builtins.property
    @pulumi.getter
    def environment(self) -> pulumi.Input[_builtins.str]:
        """
        The environment type for the SAP Single Node Virtual Instance. Possible values are `NonProd` and `Prod`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "environment")

    @environment.setter
    def environment(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "environment", value)

    @_builtins.property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Input[_builtins.str]:
        """
        The name of the Resource Group where the SAP Single Node Virtual Instance should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "resource_group_name", value)

    @_builtins.property
    @pulumi.getter(name="sapFqdn")
    def sap_fqdn(self) -> pulumi.Input[_builtins.str]:
        """
        The fully qualified domain name for the SAP system. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "sap_fqdn")

    @sap_fqdn.setter
    def sap_fqdn(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "sap_fqdn", value)

    @_builtins.property
    @pulumi.getter(name="sapProduct")
    def sap_product(self) -> pulumi.Input[_builtins.str]:
        """
        The SAP Product type for the SAP Single Node Virtual Instance. Possible values are `ECC`, `Other` and `S4HANA`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "sap_product")

    @sap_product.setter
    def sap_product(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "sap_product", value)

    @_builtins.property
    @pulumi.getter(name="singleServerConfiguration")
    def single_server_configuration(self) -> pulumi.Input['SingleNodeVirtualInstanceSingleServerConfigurationArgs']:
        """
        A `single_server_configuration` block as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "single_server_configuration")

    @single_server_configuration.setter
    def single_server_configuration(self, value: pulumi.Input['SingleNodeVirtualInstanceSingleServerConfigurationArgs']):
        pulumi.set(self, "single_server_configuration", value)

    @_builtins.property
    @pulumi.getter
    def identity(self) -> Optional[pulumi.Input['SingleNodeVirtualInstanceIdentityArgs']]:
        """
        An `identity` block as defined below.
        """
        return pulumi.get(self, "identity")

    @identity.setter
    def identity(self, value: Optional[pulumi.Input['SingleNodeVirtualInstanceIdentityArgs']]):
        pulumi.set(self, "identity", value)

    @_builtins.property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Azure Region where the SAP Single Node Virtual Instance should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "location", value)

    @_builtins.property
    @pulumi.getter(name="managedResourceGroupName")
    def managed_resource_group_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the managed Resource Group for the SAP Single Node Virtual Instance. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "managed_resource_group_name")

    @managed_resource_group_name.setter
    def managed_resource_group_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "managed_resource_group_name", value)

    @_builtins.property
    @pulumi.getter(name="managedResourcesNetworkAccessType")
    def managed_resources_network_access_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The network access type for managed resources. Possible values are `Private` and `Public`. Defaults to `Public`.
        """
        return pulumi.get(self, "managed_resources_network_access_type")

    @managed_resources_network_access_type.setter
    def managed_resources_network_access_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "managed_resources_network_access_type", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the name of this SAP Single Node Virtual Instance. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        A mapping of tags which should be assigned to the SAP Single Node Virtual Instance.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _SingleNodeVirtualInstanceState:
    def __init__(__self__, *,
                 app_location: Optional[pulumi.Input[_builtins.str]] = None,
                 environment: Optional[pulumi.Input[_builtins.str]] = None,
                 identity: Optional[pulumi.Input['SingleNodeVirtualInstanceIdentityArgs']] = None,
                 location: Optional[pulumi.Input[_builtins.str]] = None,
                 managed_resource_group_name: Optional[pulumi.Input[_builtins.str]] = None,
                 managed_resources_network_access_type: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_group_name: Optional[pulumi.Input[_builtins.str]] = None,
                 sap_fqdn: Optional[pulumi.Input[_builtins.str]] = None,
                 sap_product: Optional[pulumi.Input[_builtins.str]] = None,
                 single_server_configuration: Optional[pulumi.Input['SingleNodeVirtualInstanceSingleServerConfigurationArgs']] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering SingleNodeVirtualInstance resources.

        :param pulumi.Input[_builtins.str] app_location: The Geo-Location where the SAP system is to be created. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] environment: The environment type for the SAP Single Node Virtual Instance. Possible values are `NonProd` and `Prod`. Changing this forces a new resource to be created.
        :param pulumi.Input['SingleNodeVirtualInstanceIdentityArgs'] identity: An `identity` block as defined below.
        :param pulumi.Input[_builtins.str] location: The Azure Region where the SAP Single Node Virtual Instance should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] managed_resource_group_name: The name of the managed Resource Group for the SAP Single Node Virtual Instance. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] managed_resources_network_access_type: The network access type for managed resources. Possible values are `Private` and `Public`. Defaults to `Public`.
        :param pulumi.Input[_builtins.str] name: Specifies the name of this SAP Single Node Virtual Instance. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] resource_group_name: The name of the Resource Group where the SAP Single Node Virtual Instance should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] sap_fqdn: The fully qualified domain name for the SAP system. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] sap_product: The SAP Product type for the SAP Single Node Virtual Instance. Possible values are `ECC`, `Other` and `S4HANA`. Changing this forces a new resource to be created.
        :param pulumi.Input['SingleNodeVirtualInstanceSingleServerConfigurationArgs'] single_server_configuration: A `single_server_configuration` block as defined below. Changing this forces a new resource to be created.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] tags: A mapping of tags which should be assigned to the SAP Single Node Virtual Instance.
        """
        if app_location is not None:
            pulumi.set(__self__, "app_location", app_location)
        if environment is not None:
            pulumi.set(__self__, "environment", environment)
        if identity is not None:
            pulumi.set(__self__, "identity", identity)
        if location is not None:
            pulumi.set(__self__, "location", location)
        if managed_resource_group_name is not None:
            pulumi.set(__self__, "managed_resource_group_name", managed_resource_group_name)
        if managed_resources_network_access_type is not None:
            pulumi.set(__self__, "managed_resources_network_access_type", managed_resources_network_access_type)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if resource_group_name is not None:
            pulumi.set(__self__, "resource_group_name", resource_group_name)
        if sap_fqdn is not None:
            pulumi.set(__self__, "sap_fqdn", sap_fqdn)
        if sap_product is not None:
            pulumi.set(__self__, "sap_product", sap_product)
        if single_server_configuration is not None:
            pulumi.set(__self__, "single_server_configuration", single_server_configuration)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter(name="appLocation")
    def app_location(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Geo-Location where the SAP system is to be created. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "app_location")

    @app_location.setter
    def app_location(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "app_location", value)

    @_builtins.property
    @pulumi.getter
    def environment(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The environment type for the SAP Single Node Virtual Instance. Possible values are `NonProd` and `Prod`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "environment")

    @environment.setter
    def environment(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "environment", value)

    @_builtins.property
    @pulumi.getter
    def identity(self) -> Optional[pulumi.Input['SingleNodeVirtualInstanceIdentityArgs']]:
        """
        An `identity` block as defined below.
        """
        return pulumi.get(self, "identity")

    @identity.setter
    def identity(self, value: Optional[pulumi.Input['SingleNodeVirtualInstanceIdentityArgs']]):
        pulumi.set(self, "identity", value)

    @_builtins.property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Azure Region where the SAP Single Node Virtual Instance should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "location", value)

    @_builtins.property
    @pulumi.getter(name="managedResourceGroupName")
    def managed_resource_group_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the managed Resource Group for the SAP Single Node Virtual Instance. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "managed_resource_group_name")

    @managed_resource_group_name.setter
    def managed_resource_group_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "managed_resource_group_name", value)

    @_builtins.property
    @pulumi.getter(name="managedResourcesNetworkAccessType")
    def managed_resources_network_access_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The network access type for managed resources. Possible values are `Private` and `Public`. Defaults to `Public`.
        """
        return pulumi.get(self, "managed_resources_network_access_type")

    @managed_resources_network_access_type.setter
    def managed_resources_network_access_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "managed_resources_network_access_type", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the name of this SAP Single Node Virtual Instance. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Resource Group where the SAP Single Node Virtual Instance should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "resource_group_name", value)

    @_builtins.property
    @pulumi.getter(name="sapFqdn")
    def sap_fqdn(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The fully qualified domain name for the SAP system. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "sap_fqdn")

    @sap_fqdn.setter
    def sap_fqdn(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sap_fqdn", value)

    @_builtins.property
    @pulumi.getter(name="sapProduct")
    def sap_product(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The SAP Product type for the SAP Single Node Virtual Instance. Possible values are `ECC`, `Other` and `S4HANA`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "sap_product")

    @sap_product.setter
    def sap_product(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sap_product", value)

    @_builtins.property
    @pulumi.getter(name="singleServerConfiguration")
    def single_server_configuration(self) -> Optional[pulumi.Input['SingleNodeVirtualInstanceSingleServerConfigurationArgs']]:
        """
        A `single_server_configuration` block as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "single_server_configuration")

    @single_server_configuration.setter
    def single_server_configuration(self, value: Optional[pulumi.Input['SingleNodeVirtualInstanceSingleServerConfigurationArgs']]):
        pulumi.set(self, "single_server_configuration", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        A mapping of tags which should be assigned to the SAP Single Node Virtual Instance.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.type_token("azure:workloadssap/singleNodeVirtualInstance:SingleNodeVirtualInstance")
class SingleNodeVirtualInstance(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_location: Optional[pulumi.Input[_builtins.str]] = None,
                 environment: Optional[pulumi.Input[_builtins.str]] = None,
                 identity: Optional[pulumi.Input[Union['SingleNodeVirtualInstanceIdentityArgs', 'SingleNodeVirtualInstanceIdentityArgsDict']]] = None,
                 location: Optional[pulumi.Input[_builtins.str]] = None,
                 managed_resource_group_name: Optional[pulumi.Input[_builtins.str]] = None,
                 managed_resources_network_access_type: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_group_name: Optional[pulumi.Input[_builtins.str]] = None,
                 sap_fqdn: Optional[pulumi.Input[_builtins.str]] = None,
                 sap_product: Optional[pulumi.Input[_builtins.str]] = None,
                 single_server_configuration: Optional[pulumi.Input[Union['SingleNodeVirtualInstanceSingleServerConfigurationArgs', 'SingleNodeVirtualInstanceSingleServerConfigurationArgsDict']]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        Manages an SAP Single Node Virtual Instance with new SAP System.

        > **Note:** Before using this resource, it's required to submit the request of registering the Resource Provider with Azure CLI `az provider register --namespace "Microsoft.Workloads"`. The Resource Provider can take a while to register, you can check the status by running `az provider show --namespace "Microsoft.Workloads" --query "registrationState"`. Once this outputs "Registered" the Resource Provider is available for use.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure
        import pulumi_tls as tls

        current = azure.core.get_subscription()
        example_private_key = tls.index.PrivateKey("example",
            algorithm=RSA,
            rsa_bits=4096)
        example = tls.index.public_key(private_key_pem=example_private_key["privateKeyPem"])
        example_resource_group = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_user_assigned_identity = azure.authorization.UserAssignedIdentity("example",
            name="example-uai",
            location=example_resource_group.location,
            resource_group_name=example_resource_group.name)
        example_assignment = azure.authorization.Assignment("example",
            scope=current.id,
            role_definition_name="Azure Center for SAP solutions service role",
            principal_id=example_user_assigned_identity.principal_id)
        example_virtual_network = azure.network.VirtualNetwork("example",
            name="example-vnet",
            address_spaces=["10.0.0.0/16"],
            location=example_resource_group.location,
            resource_group_name=example_resource_group.name)
        example_subnet = azure.network.Subnet("example",
            name="example-subnet",
            resource_group_name=example_resource_group.name,
            virtual_network_name=example_virtual_network.name,
            address_prefixes=["10.0.2.0/24"])
        app = azure.core.ResourceGroup("app",
            name="example-sapapp",
            location="West Europe",
            opts = pulumi.ResourceOptions(depends_on=[example_subnet]))
        example_single_node_virtual_instance = azure.workloadssap.SingleNodeVirtualInstance("example",
            name="X05",
            resource_group_name=example_resource_group.name,
            location=example_resource_group.location,
            environment="NonProd",
            sap_product="S4HANA",
            managed_resource_group_name="managedTestRG",
            app_location=app.location,
            sap_fqdn="sap.bpaas.com",
            single_server_configuration={
                "app_resource_group_name": app.name,
                "subnet_id": example_subnet.id,
                "database_type": "HANA",
                "secondary_ip_enabled": True,
                "virtual_machine_configuration": {
                    "virtual_machine_size": "Standard_E32ds_v4",
                    "image": {
                        "offer": "RHEL-SAP-HA",
                        "publisher": "RedHat",
                        "sku": "82sapha-gen2",
                        "version": "latest",
                    },
                    "os_profile": {
                        "admin_username": "testAdmin",
                        "ssh_private_key": example_private_key["privateKeyPem"],
                        "ssh_public_key": example["publicKeyOpenssh"],
                    },
                },
                "disk_volume_configurations": [
                    {
                        "volume_name": "hana/data",
                        "number_of_disks": 3,
                        "size_in_gb": 128,
                        "sku_name": "Premium_LRS",
                    },
                    {
                        "volume_name": "hana/log",
                        "number_of_disks": 3,
                        "size_in_gb": 128,
                        "sku_name": "Premium_LRS",
                    },
                    {
                        "volume_name": "hana/shared",
                        "number_of_disks": 1,
                        "size_in_gb": 256,
                        "sku_name": "Premium_LRS",
                    },
                    {
                        "volume_name": "usr/sap",
                        "number_of_disks": 1,
                        "size_in_gb": 128,
                        "sku_name": "Premium_LRS",
                    },
                    {
                        "volume_name": "backup",
                        "number_of_disks": 2,
                        "size_in_gb": 256,
                        "sku_name": "StandardSSD_LRS",
                    },
                    {
                        "volume_name": "os",
                        "number_of_disks": 1,
                        "size_in_gb": 64,
                        "sku_name": "StandardSSD_LRS",
                    },
                ],
                "virtual_machine_resource_names": {
                    "host_name": "apphostName0",
                    "os_disk_name": "app0osdisk",
                    "virtual_machine_name": "appvm0",
                    "network_interface_names": ["appnic0"],
                    "data_disks": [{
                        "volume_name": "default",
                        "names": ["app0disk0"],
                    }],
                },
            },
            identity={
                "type": "UserAssigned",
                "identity_ids": [example_user_assigned_identity.id],
            },
            opts = pulumi.ResourceOptions(depends_on=[example_assignment]))
        ```

        ## API Providers

        <!-- This section is generated, changes will be overwritten -->
        This resource uses the following Azure API Providers:

        * `Microsoft.Workloads` - 2024-09-01

        ## Import

        SAP Single Node Virtual Instances with new SAP Systems can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:workloadssap/singleNodeVirtualInstance:SingleNodeVirtualInstance example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.Workloads/sapVirtualInstances/vis1
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] app_location: The Geo-Location where the SAP system is to be created. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] environment: The environment type for the SAP Single Node Virtual Instance. Possible values are `NonProd` and `Prod`. Changing this forces a new resource to be created.
        :param pulumi.Input[Union['SingleNodeVirtualInstanceIdentityArgs', 'SingleNodeVirtualInstanceIdentityArgsDict']] identity: An `identity` block as defined below.
        :param pulumi.Input[_builtins.str] location: The Azure Region where the SAP Single Node Virtual Instance should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] managed_resource_group_name: The name of the managed Resource Group for the SAP Single Node Virtual Instance. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] managed_resources_network_access_type: The network access type for managed resources. Possible values are `Private` and `Public`. Defaults to `Public`.
        :param pulumi.Input[_builtins.str] name: Specifies the name of this SAP Single Node Virtual Instance. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] resource_group_name: The name of the Resource Group where the SAP Single Node Virtual Instance should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] sap_fqdn: The fully qualified domain name for the SAP system. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] sap_product: The SAP Product type for the SAP Single Node Virtual Instance. Possible values are `ECC`, `Other` and `S4HANA`. Changing this forces a new resource to be created.
        :param pulumi.Input[Union['SingleNodeVirtualInstanceSingleServerConfigurationArgs', 'SingleNodeVirtualInstanceSingleServerConfigurationArgsDict']] single_server_configuration: A `single_server_configuration` block as defined below. Changing this forces a new resource to be created.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] tags: A mapping of tags which should be assigned to the SAP Single Node Virtual Instance.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SingleNodeVirtualInstanceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages an SAP Single Node Virtual Instance with new SAP System.

        > **Note:** Before using this resource, it's required to submit the request of registering the Resource Provider with Azure CLI `az provider register --namespace "Microsoft.Workloads"`. The Resource Provider can take a while to register, you can check the status by running `az provider show --namespace "Microsoft.Workloads" --query "registrationState"`. Once this outputs "Registered" the Resource Provider is available for use.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure
        import pulumi_tls as tls

        current = azure.core.get_subscription()
        example_private_key = tls.index.PrivateKey("example",
            algorithm=RSA,
            rsa_bits=4096)
        example = tls.index.public_key(private_key_pem=example_private_key["privateKeyPem"])
        example_resource_group = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_user_assigned_identity = azure.authorization.UserAssignedIdentity("example",
            name="example-uai",
            location=example_resource_group.location,
            resource_group_name=example_resource_group.name)
        example_assignment = azure.authorization.Assignment("example",
            scope=current.id,
            role_definition_name="Azure Center for SAP solutions service role",
            principal_id=example_user_assigned_identity.principal_id)
        example_virtual_network = azure.network.VirtualNetwork("example",
            name="example-vnet",
            address_spaces=["10.0.0.0/16"],
            location=example_resource_group.location,
            resource_group_name=example_resource_group.name)
        example_subnet = azure.network.Subnet("example",
            name="example-subnet",
            resource_group_name=example_resource_group.name,
            virtual_network_name=example_virtual_network.name,
            address_prefixes=["10.0.2.0/24"])
        app = azure.core.ResourceGroup("app",
            name="example-sapapp",
            location="West Europe",
            opts = pulumi.ResourceOptions(depends_on=[example_subnet]))
        example_single_node_virtual_instance = azure.workloadssap.SingleNodeVirtualInstance("example",
            name="X05",
            resource_group_name=example_resource_group.name,
            location=example_resource_group.location,
            environment="NonProd",
            sap_product="S4HANA",
            managed_resource_group_name="managedTestRG",
            app_location=app.location,
            sap_fqdn="sap.bpaas.com",
            single_server_configuration={
                "app_resource_group_name": app.name,
                "subnet_id": example_subnet.id,
                "database_type": "HANA",
                "secondary_ip_enabled": True,
                "virtual_machine_configuration": {
                    "virtual_machine_size": "Standard_E32ds_v4",
                    "image": {
                        "offer": "RHEL-SAP-HA",
                        "publisher": "RedHat",
                        "sku": "82sapha-gen2",
                        "version": "latest",
                    },
                    "os_profile": {
                        "admin_username": "testAdmin",
                        "ssh_private_key": example_private_key["privateKeyPem"],
                        "ssh_public_key": example["publicKeyOpenssh"],
                    },
                },
                "disk_volume_configurations": [
                    {
                        "volume_name": "hana/data",
                        "number_of_disks": 3,
                        "size_in_gb": 128,
                        "sku_name": "Premium_LRS",
                    },
                    {
                        "volume_name": "hana/log",
                        "number_of_disks": 3,
                        "size_in_gb": 128,
                        "sku_name": "Premium_LRS",
                    },
                    {
                        "volume_name": "hana/shared",
                        "number_of_disks": 1,
                        "size_in_gb": 256,
                        "sku_name": "Premium_LRS",
                    },
                    {
                        "volume_name": "usr/sap",
                        "number_of_disks": 1,
                        "size_in_gb": 128,
                        "sku_name": "Premium_LRS",
                    },
                    {
                        "volume_name": "backup",
                        "number_of_disks": 2,
                        "size_in_gb": 256,
                        "sku_name": "StandardSSD_LRS",
                    },
                    {
                        "volume_name": "os",
                        "number_of_disks": 1,
                        "size_in_gb": 64,
                        "sku_name": "StandardSSD_LRS",
                    },
                ],
                "virtual_machine_resource_names": {
                    "host_name": "apphostName0",
                    "os_disk_name": "app0osdisk",
                    "virtual_machine_name": "appvm0",
                    "network_interface_names": ["appnic0"],
                    "data_disks": [{
                        "volume_name": "default",
                        "names": ["app0disk0"],
                    }],
                },
            },
            identity={
                "type": "UserAssigned",
                "identity_ids": [example_user_assigned_identity.id],
            },
            opts = pulumi.ResourceOptions(depends_on=[example_assignment]))
        ```

        ## API Providers

        <!-- This section is generated, changes will be overwritten -->
        This resource uses the following Azure API Providers:

        * `Microsoft.Workloads` - 2024-09-01

        ## Import

        SAP Single Node Virtual Instances with new SAP Systems can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:workloadssap/singleNodeVirtualInstance:SingleNodeVirtualInstance example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.Workloads/sapVirtualInstances/vis1
        ```


        :param str resource_name: The name of the resource.
        :param SingleNodeVirtualInstanceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SingleNodeVirtualInstanceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_location: Optional[pulumi.Input[_builtins.str]] = None,
                 environment: Optional[pulumi.Input[_builtins.str]] = None,
                 identity: Optional[pulumi.Input[Union['SingleNodeVirtualInstanceIdentityArgs', 'SingleNodeVirtualInstanceIdentityArgsDict']]] = None,
                 location: Optional[pulumi.Input[_builtins.str]] = None,
                 managed_resource_group_name: Optional[pulumi.Input[_builtins.str]] = None,
                 managed_resources_network_access_type: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_group_name: Optional[pulumi.Input[_builtins.str]] = None,
                 sap_fqdn: Optional[pulumi.Input[_builtins.str]] = None,
                 sap_product: Optional[pulumi.Input[_builtins.str]] = None,
                 single_server_configuration: Optional[pulumi.Input[Union['SingleNodeVirtualInstanceSingleServerConfigurationArgs', 'SingleNodeVirtualInstanceSingleServerConfigurationArgsDict']]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SingleNodeVirtualInstanceArgs.__new__(SingleNodeVirtualInstanceArgs)

            if app_location is None and not opts.urn:
                raise TypeError("Missing required property 'app_location'")
            __props__.__dict__["app_location"] = app_location
            if environment is None and not opts.urn:
                raise TypeError("Missing required property 'environment'")
            __props__.__dict__["environment"] = environment
            __props__.__dict__["identity"] = identity
            __props__.__dict__["location"] = location
            __props__.__dict__["managed_resource_group_name"] = managed_resource_group_name
            __props__.__dict__["managed_resources_network_access_type"] = managed_resources_network_access_type
            __props__.__dict__["name"] = name
            if resource_group_name is None and not opts.urn:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__.__dict__["resource_group_name"] = resource_group_name
            if sap_fqdn is None and not opts.urn:
                raise TypeError("Missing required property 'sap_fqdn'")
            __props__.__dict__["sap_fqdn"] = sap_fqdn
            if sap_product is None and not opts.urn:
                raise TypeError("Missing required property 'sap_product'")
            __props__.__dict__["sap_product"] = sap_product
            if single_server_configuration is None and not opts.urn:
                raise TypeError("Missing required property 'single_server_configuration'")
            __props__.__dict__["single_server_configuration"] = single_server_configuration
            __props__.__dict__["tags"] = tags
        super(SingleNodeVirtualInstance, __self__).__init__(
            'azure:workloadssap/singleNodeVirtualInstance:SingleNodeVirtualInstance',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            app_location: Optional[pulumi.Input[_builtins.str]] = None,
            environment: Optional[pulumi.Input[_builtins.str]] = None,
            identity: Optional[pulumi.Input[Union['SingleNodeVirtualInstanceIdentityArgs', 'SingleNodeVirtualInstanceIdentityArgsDict']]] = None,
            location: Optional[pulumi.Input[_builtins.str]] = None,
            managed_resource_group_name: Optional[pulumi.Input[_builtins.str]] = None,
            managed_resources_network_access_type: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            resource_group_name: Optional[pulumi.Input[_builtins.str]] = None,
            sap_fqdn: Optional[pulumi.Input[_builtins.str]] = None,
            sap_product: Optional[pulumi.Input[_builtins.str]] = None,
            single_server_configuration: Optional[pulumi.Input[Union['SingleNodeVirtualInstanceSingleServerConfigurationArgs', 'SingleNodeVirtualInstanceSingleServerConfigurationArgsDict']]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None) -> 'SingleNodeVirtualInstance':
        """
        Get an existing SingleNodeVirtualInstance resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] app_location: The Geo-Location where the SAP system is to be created. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] environment: The environment type for the SAP Single Node Virtual Instance. Possible values are `NonProd` and `Prod`. Changing this forces a new resource to be created.
        :param pulumi.Input[Union['SingleNodeVirtualInstanceIdentityArgs', 'SingleNodeVirtualInstanceIdentityArgsDict']] identity: An `identity` block as defined below.
        :param pulumi.Input[_builtins.str] location: The Azure Region where the SAP Single Node Virtual Instance should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] managed_resource_group_name: The name of the managed Resource Group for the SAP Single Node Virtual Instance. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] managed_resources_network_access_type: The network access type for managed resources. Possible values are `Private` and `Public`. Defaults to `Public`.
        :param pulumi.Input[_builtins.str] name: Specifies the name of this SAP Single Node Virtual Instance. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] resource_group_name: The name of the Resource Group where the SAP Single Node Virtual Instance should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] sap_fqdn: The fully qualified domain name for the SAP system. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] sap_product: The SAP Product type for the SAP Single Node Virtual Instance. Possible values are `ECC`, `Other` and `S4HANA`. Changing this forces a new resource to be created.
        :param pulumi.Input[Union['SingleNodeVirtualInstanceSingleServerConfigurationArgs', 'SingleNodeVirtualInstanceSingleServerConfigurationArgsDict']] single_server_configuration: A `single_server_configuration` block as defined below. Changing this forces a new resource to be created.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] tags: A mapping of tags which should be assigned to the SAP Single Node Virtual Instance.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SingleNodeVirtualInstanceState.__new__(_SingleNodeVirtualInstanceState)

        __props__.__dict__["app_location"] = app_location
        __props__.__dict__["environment"] = environment
        __props__.__dict__["identity"] = identity
        __props__.__dict__["location"] = location
        __props__.__dict__["managed_resource_group_name"] = managed_resource_group_name
        __props__.__dict__["managed_resources_network_access_type"] = managed_resources_network_access_type
        __props__.__dict__["name"] = name
        __props__.__dict__["resource_group_name"] = resource_group_name
        __props__.__dict__["sap_fqdn"] = sap_fqdn
        __props__.__dict__["sap_product"] = sap_product
        __props__.__dict__["single_server_configuration"] = single_server_configuration
        __props__.__dict__["tags"] = tags
        return SingleNodeVirtualInstance(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="appLocation")
    def app_location(self) -> pulumi.Output[_builtins.str]:
        """
        The Geo-Location where the SAP system is to be created. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "app_location")

    @_builtins.property
    @pulumi.getter
    def environment(self) -> pulumi.Output[_builtins.str]:
        """
        The environment type for the SAP Single Node Virtual Instance. Possible values are `NonProd` and `Prod`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "environment")

    @_builtins.property
    @pulumi.getter
    def identity(self) -> pulumi.Output[Optional['outputs.SingleNodeVirtualInstanceIdentity']]:
        """
        An `identity` block as defined below.
        """
        return pulumi.get(self, "identity")

    @_builtins.property
    @pulumi.getter
    def location(self) -> pulumi.Output[_builtins.str]:
        """
        The Azure Region where the SAP Single Node Virtual Instance should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "location")

    @_builtins.property
    @pulumi.getter(name="managedResourceGroupName")
    def managed_resource_group_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The name of the managed Resource Group for the SAP Single Node Virtual Instance. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "managed_resource_group_name")

    @_builtins.property
    @pulumi.getter(name="managedResourcesNetworkAccessType")
    def managed_resources_network_access_type(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The network access type for managed resources. Possible values are `Private` and `Public`. Defaults to `Public`.
        """
        return pulumi.get(self, "managed_resources_network_access_type")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies the name of this SAP Single Node Virtual Instance. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the Resource Group where the SAP Single Node Virtual Instance should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @_builtins.property
    @pulumi.getter(name="sapFqdn")
    def sap_fqdn(self) -> pulumi.Output[_builtins.str]:
        """
        The fully qualified domain name for the SAP system. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "sap_fqdn")

    @_builtins.property
    @pulumi.getter(name="sapProduct")
    def sap_product(self) -> pulumi.Output[_builtins.str]:
        """
        The SAP Product type for the SAP Single Node Virtual Instance. Possible values are `ECC`, `Other` and `S4HANA`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "sap_product")

    @_builtins.property
    @pulumi.getter(name="singleServerConfiguration")
    def single_server_configuration(self) -> pulumi.Output['outputs.SingleNodeVirtualInstanceSingleServerConfiguration']:
        """
        A `single_server_configuration` block as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "single_server_configuration")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, _builtins.str]]]:
        """
        A mapping of tags which should be assigned to the SAP Single Node Virtual Instance.
        """
        return pulumi.get(self, "tags")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'MongoClusterConnectionStringArgs',
    'MongoClusterConnectionStringArgsDict',
    'MongoClusterCustomerManagedKeyArgs',
    'MongoClusterCustomerManagedKeyArgsDict',
    'MongoClusterIdentityArgs',
    'MongoClusterIdentityArgsDict',
    'MongoClusterRestoreArgs',
    'MongoClusterRestoreArgsDict',
    'UserRoleArgs',
    'UserRoleArgsDict',
]

class MongoClusterConnectionStringArgsDict(TypedDict):
    description: NotRequired[pulumi.Input[_builtins.str]]
    """
    The description of the connection string.
    """
    name: NotRequired[pulumi.Input[_builtins.str]]
    """
    The name which should be used for the MongoDB Cluster. Changing this forces a new resource to be created.
    """
    value: NotRequired[pulumi.Input[_builtins.str]]
    """
    The value of the Mongo Cluster connection string. The `<user>:<password>` placeholder returned from API will be replaced by the real `administrator_username` and `administrator_password` if available in the state.
    """

@pulumi.input_type
class MongoClusterConnectionStringArgs:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] description: The description of the connection string.
        :param pulumi.Input[_builtins.str] name: The name which should be used for the MongoDB Cluster. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] value: The value of the Mongo Cluster connection string. The `<user>:<password>` placeholder returned from API will be replaced by the real `administrator_username` and `administrator_password` if available in the state.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the connection string.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name which should be used for the MongoDB Cluster. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The value of the Mongo Cluster connection string. The `<user>:<password>` placeholder returned from API will be replaced by the real `administrator_username` and `administrator_password` if available in the state.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "value", value)


class MongoClusterCustomerManagedKeyArgsDict(TypedDict):
    key_vault_key_id: pulumi.Input[_builtins.str]
    """
    The ID of the key vault key used for encryption. For example: `https://example-vault-name.vault.azure.net/keys/example-key-name`.
    """
    user_assigned_identity_id: pulumi.Input[_builtins.str]
    """
    The ID of the User Assigned Identity that has access to the Key Vault Key.
    """

@pulumi.input_type
class MongoClusterCustomerManagedKeyArgs:
    def __init__(__self__, *,
                 key_vault_key_id: pulumi.Input[_builtins.str],
                 user_assigned_identity_id: pulumi.Input[_builtins.str]):
        """
        :param pulumi.Input[_builtins.str] key_vault_key_id: The ID of the key vault key used for encryption. For example: `https://example-vault-name.vault.azure.net/keys/example-key-name`.
        :param pulumi.Input[_builtins.str] user_assigned_identity_id: The ID of the User Assigned Identity that has access to the Key Vault Key.
        """
        pulumi.set(__self__, "key_vault_key_id", key_vault_key_id)
        pulumi.set(__self__, "user_assigned_identity_id", user_assigned_identity_id)

    @_builtins.property
    @pulumi.getter(name="keyVaultKeyId")
    def key_vault_key_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the key vault key used for encryption. For example: `https://example-vault-name.vault.azure.net/keys/example-key-name`.
        """
        return pulumi.get(self, "key_vault_key_id")

    @key_vault_key_id.setter
    def key_vault_key_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "key_vault_key_id", value)

    @_builtins.property
    @pulumi.getter(name="userAssignedIdentityId")
    def user_assigned_identity_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the User Assigned Identity that has access to the Key Vault Key.
        """
        return pulumi.get(self, "user_assigned_identity_id")

    @user_assigned_identity_id.setter
    def user_assigned_identity_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "user_assigned_identity_id", value)


class MongoClusterIdentityArgsDict(TypedDict):
    identity_ids: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]
    """
    A list of one or more Resource IDs for User Assigned Managed identities to assign.

    > **Note:** Required when `type` is set to `UserAssigned`.
    """
    type: pulumi.Input[_builtins.str]
    """
    The type of managed identity to assign. Possible value is `UserAssigned`.
    """

@pulumi.input_type
class MongoClusterIdentityArgs:
    def __init__(__self__, *,
                 identity_ids: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]],
                 type: pulumi.Input[_builtins.str]):
        """
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] identity_ids: A list of one or more Resource IDs for User Assigned Managed identities to assign.
               
               > **Note:** Required when `type` is set to `UserAssigned`.
        :param pulumi.Input[_builtins.str] type: The type of managed identity to assign. Possible value is `UserAssigned`.
        """
        pulumi.set(__self__, "identity_ids", identity_ids)
        pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter(name="identityIds")
    def identity_ids(self) -> pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]:
        """
        A list of one or more Resource IDs for User Assigned Managed identities to assign.

        > **Note:** Required when `type` is set to `UserAssigned`.
        """
        return pulumi.get(self, "identity_ids")

    @identity_ids.setter
    def identity_ids(self, value: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]):
        pulumi.set(self, "identity_ids", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Input[_builtins.str]:
        """
        The type of managed identity to assign. Possible value is `UserAssigned`.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "type", value)


class MongoClusterRestoreArgsDict(TypedDict):
    point_in_time_utc: pulumi.Input[_builtins.str]
    """
    The point in time (in UTC) to restore from, in ISO 8601 format (e.g., `2024-01-01T00:00:00Z`). Changing this forces a new resource to be created.
    """
    source_id: pulumi.Input[_builtins.str]
    """
    The ID of the source MongoDB Cluster to restore from. Changing this forces a new resource to be created.
    """

@pulumi.input_type
class MongoClusterRestoreArgs:
    def __init__(__self__, *,
                 point_in_time_utc: pulumi.Input[_builtins.str],
                 source_id: pulumi.Input[_builtins.str]):
        """
        :param pulumi.Input[_builtins.str] point_in_time_utc: The point in time (in UTC) to restore from, in ISO 8601 format (e.g., `2024-01-01T00:00:00Z`). Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] source_id: The ID of the source MongoDB Cluster to restore from. Changing this forces a new resource to be created.
        """
        pulumi.set(__self__, "point_in_time_utc", point_in_time_utc)
        pulumi.set(__self__, "source_id", source_id)

    @_builtins.property
    @pulumi.getter(name="pointInTimeUtc")
    def point_in_time_utc(self) -> pulumi.Input[_builtins.str]:
        """
        The point in time (in UTC) to restore from, in ISO 8601 format (e.g., `2024-01-01T00:00:00Z`). Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "point_in_time_utc")

    @point_in_time_utc.setter
    def point_in_time_utc(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "point_in_time_utc", value)

    @_builtins.property
    @pulumi.getter(name="sourceId")
    def source_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the source MongoDB Cluster to restore from. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "source_id")

    @source_id.setter
    def source_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "source_id", value)


class UserRoleArgsDict(TypedDict):
    database: pulumi.Input[_builtins.str]
    """
    The name of the database to which the role will be applied. Changing this forces a new resource to be created.
    """
    name: pulumi.Input[_builtins.str]
    """
    The role name. The only possible value is `root`. Changing this forces a new resource to be created.
    """

@pulumi.input_type
class UserRoleArgs:
    def __init__(__self__, *,
                 database: pulumi.Input[_builtins.str],
                 name: pulumi.Input[_builtins.str]):
        """
        :param pulumi.Input[_builtins.str] database: The name of the database to which the role will be applied. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] name: The role name. The only possible value is `root`. Changing this forces a new resource to be created.
        """
        pulumi.set(__self__, "database", database)
        pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter
    def database(self) -> pulumi.Input[_builtins.str]:
        """
        The name of the database to which the role will be applied. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "database")

    @database.setter
    def database(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "database", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Input[_builtins.str]:
        """
        The role name. The only possible value is `root`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "name", value)


